===============
bluesky-widgets
===============

.. image:: https://img.shields.io/travis/danielballan/bluesky-widgets.svg
        :target: https://travis-ci.org/danielballan/bluesky-widgets

.. image:: https://img.shields.io/pypi/v/bluesky-widgets.svg
        :target: https://pypi.python.org/pypi/bluesky-widgets

.. image:: https://img.shields.io/codecov/c/github/bluesky/bluesky-widgets
        :target: https://codecov.io/gh/bluesky/bluesky-widgets

Toolbox of widgets for visualizing blueskying data
